using System.IO;
using System.Text;
using InfiniTec.Configuration.Install;

namespace InfiniTec.Configuration.Install
{
    class InstallerLogTextWriter : TextWriter
    {
        private readonly StringBuilder _Buffer = new StringBuilder();
        private int _LastCheckedIndex;

        public override Encoding Encoding
        {
            get { return Encoding.UTF8; }
        }

        public override void Write(char value)
        {
            _Buffer.Append(value);
            FlushCompleteLines();
        }

        public override void Write(string value)
        {
            _Buffer.Append(value);
            FlushCompleteLines();
        }

        private void FlushCompleteLines()
        {
            while (_LastCheckedIndex < _Buffer.Length - 1)
            {
                if (_Buffer[_LastCheckedIndex] == '\r' && _Buffer[_LastCheckedIndex + 1] == '\n')
                {
                    string line = _Buffer.ToString().Substring(0, _LastCheckedIndex);

                    if (!string.IsNullOrEmpty(line))
                    {
                        InstallerContext.Current.LogMessage(line);
                        _Buffer.Remove(0, _LastCheckedIndex + 2);
                        _LastCheckedIndex = 0;
                    }
                }

                _LastCheckedIndex++;
            }
        }
    }
}