using System;
using System.Collections;

namespace InfiniTec.Configuration.Install
{
    public class RecordCollection : CollectionBase, IDisposable
    {
        private bool _Disposed;

        /// <summary>
        /// The <see cref="Record"/>list.
        /// </summary>
        /// <param name="index">The ordinal of the <see cref="Record"/>.</param>
        /// <returns>The specified <see cref="Record"/>.</returns>
        public Record this[int index]
        {
            get
            {
                ThrowIfDisposed();
                return (Record) InnerList[index];
            }
            set
            {
                ThrowIfDisposed();
                InnerList[index] = value;
            }
        }

        #region IDisposable Members

        /// <summary>
        /// Performs application-defined tasks associated with freeing, releasing, or resetting unmanaged resources.
        /// </summary>
        public void Dispose()
        {
            Dispose(true);
            GC.SuppressFinalize(this);
        }

        #endregion

        /// <summary>
        /// Adds a <see cref="Record"/> to the <see cref="RecordCollection"/>.
        /// </summary>
        /// <param name="value">The <see cref="Record"/> to add.</param>
        public void Add(Record value)
        {
            ThrowIfDisposed();
            InnerList.Add(value);
        }

        /// <summary>
        /// Removes a <see cref="Record"/> from the <see cref="RecordCollection"/>.
        /// </summary>
        /// <param name="value">The <see cref="Record"/> to remove.</param>
        public void Remove(Record value)
        {
            ThrowIfDisposed();
            InnerList.Remove(value);
        }

        /// <summary>
        /// Finalizes this instance.
        /// </summary>
        ~RecordCollection()
        {
            if (!_Disposed)
            {
                Dispose(false);
            }
        }

        /// <summary>
        /// Performs application-defined tasks associated with freeing, releasing, or resetting unmanaged resources.
        /// </summary>
        /// <param name="disposing"><see langword="true"/> if the object is currently disposing; otherwise, <see langword="false"/>.</param>
        protected virtual void Dispose(bool disposing)
        {
            ThrowIfDisposed();

            if (disposing)
            {
                // Release my managed resources.
                foreach (Record r in this)
                {
                    r.Dispose();
                }

                Clear();
            }
            // Release my unmanaged resources.


            _Disposed = true;
        }

        /// <summary>
        /// Throws an <see cref="ObjectDisposedException"/> if this instance is already disposed.
        /// </summary>
        protected void ThrowIfDisposed()
        {
            if (_Disposed)
            {
                throw new ObjectDisposedException(GetType().Name);
            }
        }
    }
}